/***************************************************************************
                          KChildConnect.h  -  description
                             -------------------
    begin                : Tue May 2 2000
    copyright            : (C) 2000 by Martin Heni
    email                : martin@heni-online.de
 ***************************************************************************/

#ifndef _KCHILDCONNECT_H_
#define _KCHILDCONNECT_H_

#include <tqobject.h>
#include <tqstrlist.h>
#include "KEMessage.h"


class KChildConnect: public TQObject
{
  Q_OBJECT
  TQ_OBJECT

  protected:
  TQStrList inputcache;
  bool input_pending;
  TQString inputbuffer;
  int ID;

  public:
  KChildConnect();
  ~KChildConnect();
  void Receive(TQString input);
  int QueryID();
  void SetID(int id);

  virtual bool SendMsg(KEMessage *msg);
  virtual bool Send(TQString str);
  virtual KR_STATUS QuerytqStatus();

  public slots:


  signals:
  void signalReceiveMsg(KEMessage *msg,int id); 
};

#endif
